@@ -31,7 +31,7 @@ rgl.enum( attrib, vertices=1, normals=2, colors=3, texcoords=4, dim=5,
           texts=6, cex=7, adj=8, radii=9, centers=10, ids=11, 
           usermatrix=12, types=13, flags=14, offsets=15,
 	        family=16, font=17, pos=18, fogscale=19, axes=20,
-          indices=21)
+          indices=21, shapenum=22)
 
 rgl.enum.pixfmt <- function(fmt)
 rgl.enum( fmt, png=0 )
