@@ -8,8 +8,10 @@ using namespace rgl;
 //   LineSet
 //
 
-LineSet::LineSet(Material& in_material, int in_nvertices, double* in_vertices, bool in_ignoreExtent, bool in_bboxChange) 
-  : PrimitiveSet(in_material, in_nvertices, in_vertices, GL_LINES, 2, in_ignoreExtent, in_bboxChange)
+LineSet::LineSet(Material& in_material, int in_nvertices, double* in_vertices, bool in_ignoreExtent, 
+                 int in_nindices, int* in_indices, bool in_bboxChange) 
+  : PrimitiveSet(in_material, in_nvertices, in_vertices, GL_LINES, 2, in_ignoreExtent, 
+    in_nindices, in_indices, in_bboxChange)
 {
   material.lit = false;
   if (material.line_antialias) blended = true;
